# Tokopedia React Development Kits (Treats)
[![lerna](https://img.shields.io/badge/maintained%20with-lerna-cc00ff.svg)](https://lernajs.io/)
[![tested with jest](https://img.shields.io/badge/tested_with-jest-99424f.svg)](https://github.com/facebook/jest)
[![CircleCI](https://circleci.com/gh/tokopedia/treats/tree/master.svg?style=svg&circle-token=c731ca16a0ba50297243da9283308a0b1e1ef38c)](https://circleci.com/gh/tokopedia/treats/tree/master)

![Treats](./docusaurus/images/treats.png)

Learn more on our [documentation][github-treats].

## Getting Started
To get started with Treats, you can simply do the following:

```
> npm install -g create-treats-app
> create-treats-app
> cd /YOUR/APP/DIRECTORY
> yarn start
```

You don't need to configure webpack, babel, or any other build tools by yourself

## What's in the box?
1. React, JSX, ES6, and Flow (or TypeScript) syntax support.
2. Preconfigured Redux, GraphQL client and i18n out-of-the-box. *(You can disable Redux/GraphQL client if you're not using it, it'll only leave minimum trace in your build)*
3. Server-side rendering, code-splitting and hot-module replacement configured out-of-the-box.
4. CSS Modules support with CSS, LESS, or SASS syntax with autoprefixer, or use any CSS-in-JS library that you like!
5. A build script to bundle JS, CSS, images and other medias for production.
6. Built-in code generator so you wouldn't need to wrote another boilerplate codes.
7. Work out of the box with zero configuration for light usage, but easily customizable for power users. Treats is customizable with:
    - Custom Helpers (Server-side)
    - Custom Middlewares (Server-side)
    - Custom React App, Server App, GraphQL client & Redux Implementation, etc
    - Custom Webpack, Babel & PostCSS Config
8. Filesystem as your API *(all entry hooks file and folder are under `src/_**`)*

## Requirements
1. Node > 8.00

## Contributors
Thanks goes to these wonderful people ([emoji key][emojis]):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore -->
| [<img src="https://avatars3.githubusercontent.com/u/6160832" width="100px;"/><br /><sub><b>Felix Tan</b></sub>](https://github.com/regalius)<br />[💻](https://github.com/tokopedia/treats/commits?author=regalius "Code") [📖](https://github.com/tokopedia/treats/commits?author=regalius "Documentation") [💬](#question-regalius "Answering Questions") [👀](#review-regalius "Reviewed Pull Requests") [💡](#example-regalius "Examples") | [<img src="https://avatars.githubusercontent.com/u/16898682?v=3" width="100px;"/><br /><sub><b>Martino Christanto K</b></sub>](https://github.com/martinock)<br />[💻](https://github.com/tokopedia/treats/commits?author=martinock "Code") [📖](https://github.com/tokopedia/treats/commits?author=martinock "Documentation") [💬](#question-martinock "Answering Questions") [💡](#example-martinock "Examples") [✅](#tutorial-martinock "Tutorials") | [<img src="https://avatars2.githubusercontent.com/u/416498?v=4" width="100px;"/><br /><sub><b>Fadli Trias</b></sub>](https://github.com/fadlinux)<br />[💻](https://github.com/tokopedia/treats/commits?author=fadlinux "Code") [📖](https://github.com/tokopedia/treats/commits?author=fadlinux "Documentation") [💬](#question-fadlinux "Answering Questions") [💡](#example-fadlinux "Examples") [✅](#tutorial-fadlinux "Tutorials") | [<img src="https://avatars0.githubusercontent.com/u/23188218?v=4" width="100px;"/><br /><sub><b>Salman Al Fariz</b></sub>](https://github.com/salmanalfariz24)<br />[💻](https://github.com/tokopedia/treats/commits?author=salmanalfariz24 "Code") [📖](https://github.com/tokopedia/treats/commits?author=salmanalfariz24 "Documentation") [💬](#question-salmanalfariz24 "Answering Questions") [✅](#tutorial-salmanalfariz24 "Tutorials") | [<img src="https://avatars1.githubusercontent.com/u/33221847?v=4" width="100px;"/><br /><sub><b>William Candra</b></sub>](https://github.com/RiftSplitter)<br />[💻](https://github.com/tokopedia/treats/commits?author=RiftSplitter "Code") [📖](https://github.com/tokopedia/treats/commits?author=RiftSplitter "Documentation") [💬](#question-RiftSplitter "Answering Questions") [✅](#tutorial-RiftSplitter "Tutorials") | [<img src="https://avatars1.githubusercontent.com/u/31308706?v=3" width="100px;"/><br /><sub><b>Alchrist Leo</b></sub>](https://github.com/alchristleo)<br />[💻](https://github.com/tokopedia/treats/commits?author=alchristleo "Code") [📖](https://github.com/tokopedia/treats/commits?author=alchristleo "Documentation") [💡](#example-alchristleo "Examples") [✅](#tutorial-alchristleo "Tutorials") |
| :---: | :---: | :---: | :---: | :---: | :---: |
| [<img src="https://avatars0.githubusercontent.com/u/112008" width="100px;"/><br /><sub><b>Gian Giovani</b></sub>](https://github.com/fadlinux)<br />[💻](https://github.com/tokopedia/treats/commits?author=wejick "Code") [🤔](#ideas-wejick "Ideas, Planning, & Feedback") [📖](https://github.com/tokopedia/treats/commits?author=wejick "Documentation") [💡](#example-wejick "Examples") [💬](#question-wejick "Answering Questions") | [<img src="https://avatars2.githubusercontent.com/u/11306368" width="100px;"/><br /><sub><b>Stephanus Tedy</b></sub>](https://github.com/stephanustedy)<br />[💻](https://github.com/tokopedia/treats/commits?author=stephanustedy "Code") [🤔](#ideas-stephanustedy "Ideas, Planning, & Feedback") [👀](#review-stephanustedy "Reviewed Pull Requests") [📖](https://github.com/tokopedia/treats/commits?author=stephanustedy "Documentation") [💬](#question-stephanustedy "Answering Questions") | [<img src="https://avatars2.githubusercontent.com/u/24540145" width="100px;"/><br /><sub><b>Ferry Sutanto</b></sub>](https://github.com/daecide)<br />[🤔](#ideas-daecide "Ideas, Planning, & Feedback") | [<img src="https://avatars2.githubusercontent.com/u/1622646" width="100px;"/><br /><sub><b>Albert Widiatmoko</b></sub>](https://github.com/albertwidi)<br />[🤔](#ideas-albertwidi "Ideas, Planning, & Feedback") | [<img src="https://avatars3.githubusercontent.com/u/11482819" width="100px;"/><br /><sub><b>Bayu Rizky Ramadhan</b></sub>](https://github.com/codeforpizza)<br />[🤔](#ideas-codeforpizza "Ideas, Planning, & Feedback") | [<img src="https://avatars2.githubusercontent.com/u/30400435" width="100px;"/><br /><sub><b>Diagnosa Fenomena</b></sub>](https://github.com/diagnosa-f)<br />[🤔](#ideas-diagnosa-f "Ideas, Planning, & Feedback") |
| [<img src="https://avatars3.githubusercontent.com/u/625072" width="100px;"/><br /><sub><b>Essa Jiwa P</b></sub>](https://github.com/essajiwa)<br />[🤔](#ideas-essajiwa "Ideas, Planning, & Feedback") | [<img src="https://avatars1.githubusercontent.com/u/30681410" width="100px;"/><br /><sub><b>Afif Khaidir</b></sub>](https://github.com/afifkhaidir-tkpd)<br />[🐛](https://github.com/tokopedia/treats/issues?q=author%3Aafifkhaidir-tkpd "Bug reports") [🤔](#ideas-afifkhaidir-tkpd "Ideas, Planning, & Feedback") | [<img src="https://avatars3.githubusercontent.com/u/2656058" width="100px;"/><br /><sub><b>Rio Bahtiar</b></sub>](https://github.com/riobahtiar)<br />[🐛](https://github.com/tokopedia/treats/issues?q=author%3Ariobahtiar "Bug reports") [🤔](#ideas-riobahtiar "Ideas, Planning, & Feedback") | [<img src="https://avatars3.githubusercontent.com/u/12596467" width="100px;"/><br /><sub><b>Elbert Christoper</b></sub>](https://github.com/elbertcl)<br />[🐛](https://github.com/tokopedia/treats/issues?q=author%3Aelbertcl "Bug reports") [🤔](#ideas-elbertcl "Ideas, Planning, & Feedback") | [<img src="https://avatars2.githubusercontent.com/u/11177589" width="100px;"/><br /><sub><b>Ahmad Darmawan</b></sub>](https://github.com/adarwawan)<br />[🐛](https://github.com/tokopedia/treats/issues?q=author%3Aadarwawan "Bug reports") | [<img src="https://avatars3.githubusercontent.com/u/30250871" width="100px;"/><br /><sub><b>Adi Primadharma</b></sub>](https://github.com/adiprimadharma)<br />[🐛](https://github.com/tokopedia/treats/issues?q=author%3Aadiprimadharma "Bug reports") [🤔](#ideas-adiprimadharma "Ideas, Planning, & Feedback") |
| [<img src="https://avatars1.githubusercontent.com/u/26212432" width="100px;"/><br /><sub><b>Andhika Setiadi</b></sub>](https://github.com/dikasetiadi)<br />[🐛](https://github.com/tokopedia/treats/issues?q=author%3Adikasetiadi "Bug reports") [🤔](#ideas-dikasetiadi "Ideas, Planning, & Feedback") | [<img src="https://avatars3.githubusercontent.com/u/43945767?v=4" width="100px;"/><br /><sub><b>Miqdad Abdurrahman Fawwaz</b></sub>](https://miqdadfawwaz.com)<br />[📖](https://github.com/tokopedia/treats/commits?author=miqdadfwz "Documentation") | [<img src="https://avatars1.githubusercontent.com/u/36393828?v=4" width="100px;"/><br /><sub><b>Muhammad Reyhan Fahlevi</b></sub>](https://github.com/reyhanfahlevi)<br />[🐛](https://github.com/tokopedia/treats/issues?q=author%3Areyhanfahlevi "Bug reports") |
<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/kentcdodds/all-contributors) specification. Contributions of any kind are welcome!

## License
Apache 2.0

[emojis]: https://github.com/kentcdodds/all-contributors#emoji-key
[github-treats]: https://tokopedia.github.io/treats
